<?php

/**
 * @file
 * Contains Drupal\multiple_registration\AvailableUserRolesService.
 */

namespace Drupal\multiple_registration;

class AvailableUserRolesService {

  /**
   * Get all roles with ability to create registration page.
   * 
   * @return array.
   */
  public function getAvailableRoles() {
    $roles = user_role_names();
    $admin_role = \Drupal::config('user.settings')->get('admin_role');
    $notAvalible = array(
      DRUPAL_ANONYMOUS_RID => $roles[DRUPAL_ANONYMOUS_RID],
      DRUPAL_AUTHENTICATED_RID => $roles[DRUPAL_AUTHENTICATED_RID],
      $admin_role => $roles[$admin_role],
    );

    return array_diff_assoc($roles, $notAvalible);
  }

  /**
   * Get all role ids for whom registration forms was created.
   *
   * @return mixed
   *   If registration forms exists, array of paths.
   *   In other situation - FALSE.
   */
  public function getRegistrationPages() {
    $roles = $this->getAvailableRoles();
    if (!empty($roles)) {
      $pages_config = \Drupal::configFactory()->getEditable('multiple_registration.create_registration_page_form_config');
      $reg_pages = array();
      foreach ($roles as $rid => $role_name) {
        if ($url = $pages_config->get('multiple_registration_url_' . $rid)) {
          $reg_pages[$rid]['url'] = $url;
          $reg_pages[$rid]['role_name'] = $role_name;
        }
      }
      return $reg_pages;
    }
    return FALSE;
  }

}
